import fs from 'fs';
import path from 'path';
import { storage } from './storage';

/**
 * This script fixes the database with the correct data from the incidents.csv file
 */
async function fixData() {
  try {
    const csvPath = path.resolve('./data/incidents.csv');
    if (!fs.existsSync(csvPath)) {
      console.error('CSV file not found');
      return;
    }

    // Get current data to be updated
    const existingData = await storage.getIncidents(1, 100);
    
    // Get raw file content to ensure we process it correctly
    const fileContent = fs.readFileSync(csvPath, 'utf8');
    const rows = fileContent.trim().split('\n');
    
    // Skip header
    const dataRows = rows.slice(1);
    
    for (let i = 0; i < dataRows.length && i < existingData.data.length; i++) {
      const row = dataRows[i];
      const columns = row.split(',');
      
      // Get the OIC column - should be position 7 (zero-based)
      // Check if there are enough columns and OIC column exists
      if (columns.length >= 8) {
        const officerName = columns[7].trim().replace(/"/g, '');
        
        if (officerName && existingData.data[i]) {
          // Update the incident with the officer name
          const updatedIncident = {
            ...existingData.data[i],
            officerInCharge: officerName
          };
          
          // Use the storage method to update the incident
          await storage.updateIncident(existingData.data[i].id, updatedIncident);
          console.log(`Updated incident ${existingData.data[i].id} with OIC: ${officerName}`);
        }
      }
    }
    
    console.log('Data fix complete');
  } catch (error) {
    console.error('Error fixing data:', error);
  }
}

// Export the function to be called from the main server
export { fixData };